"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = DartBoard;
var _reactNative = require("react-native");
var _reactNativeSvg = require("react-native-svg");
var _constants = require("./constants");
var _bullseye = _interopRequireDefault(require("./bullseye"));
var _ringNumber = _interopRequireDefault(require("./ring-number"));
var _segment = _interopRequireDefault(require("./segment"));
var _dartboardContext = require("./dartboard-context");
var _react = _interopRequireDefault(require("react"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const styles = _reactNative.StyleSheet.create({
  mainView: {
    alignItems: 'center',
    justifyContent: 'center'
  }
});
function DartBoard({
  diameter,
  highlightedScores,
  onPress
}) {
  const doubleHeight = diameter / 20;
  const trebleHeight = diameter / 20;
  const outerBullHeight = diameter / 20;
  const innerBullHeight = diameter / 20;
  const outerRadius = diameter / 2;
  const innerRadius = diameter / 2 - diameter / 10;
  const doubleRadius = innerRadius - doubleHeight;
  const trebleRadius = innerRadius * (11 / 17);
  const innerSingleRadius = trebleRadius - trebleHeight;
  const bullRadius = innerBullHeight + outerBullHeight;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_reactNative.StyleSheet.absoluteFill, styles.mainView]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Svg, {
    height: diameter,
    width: diameter,
    viewBox: `0 0 ${diameter} ${diameter}`
  }, /*#__PURE__*/_react.default.createElement(_dartboardContext.DartboardContext.Provider, {
    value: {
      outerRadius,
      innerRadius,
      doubleRadius,
      trebleRadius,
      innerSingleRadius,
      doubleHeight,
      trebleHeight,
      outerBullHeight,
      innerBullHeight,
      bullRadius,
      highlightedScores,
      onPress
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Circle, {
    cx: outerRadius,
    cy: outerRadius,
    r: outerRadius,
    fill: "#000000"
  }), /*#__PURE__*/_react.default.createElement(_reactNativeSvg.G, {
    stroke: "#C0C0C0"
  }, [...Array(10).keys()].map(segmentIndex => {
    const redStartAngle = segmentIndex * 36 - 9;
    const greenStartAngle = segmentIndex * 36 + 9;
    const redValue = _constants.NUMBER_MAP[segmentIndex * 2];
    const greenValue = _constants.NUMBER_MAP[segmentIndex * 2 + 1];
    return /*#__PURE__*/_react.default.createElement(_reactNativeSvg.G, {
      key: `segment-pair-${segmentIndex}`
    }, /*#__PURE__*/_react.default.createElement(_segment.default, {
      startAngle: redStartAngle,
      value: redValue,
      singleColor: "#000000",
      multiColor: "#FF0000"
    }), /*#__PURE__*/_react.default.createElement(_segment.default, {
      startAngle: greenStartAngle,
      value: greenValue,
      singleColor: "#E7E4C7",
      multiColor: "#00A000"
    }));
  }), /*#__PURE__*/_react.default.createElement(_bullseye.default, null)), /*#__PURE__*/_react.default.createElement(_reactNativeSvg.G, {
    fontSize: "28px",
    textAnchor: "middle",
    fill: "#C0C0C0",
    fillOpacity: 1,
    fontFamily: "Sans"
  }, [...Array(20).keys()].map(segmentIndex => {
    return /*#__PURE__*/_react.default.createElement(_ringNumber.default, {
      key: segmentIndex,
      segmentIndex: segmentIndex
    });
  })))));
}
//# sourceMappingURL=index.js.map